@@ -1,7 +1,6 @@
 /* fbui.c: Routines for dealing with the linux fbdev user interface
    Copyright (c) 2000-2004 Philip Kendall, Matan Ziv-Av, Witold Filipczyk
-
-   $Id: fbui.c 4109 2009-12-27 06:15:10Z fredm $
+   Copyright (c) 2015 Stuart Brady
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -81,14 +80,14 @@ ui_init( int *argc, char ***argv )
   return 0;
 }
 
-int ui_event()
+int ui_event( void )
 {
   keyboard_update();
   mouse_update();
   return 0;
 }
 
-int ui_end(void)
+int ui_end( void )
 {
   /* Cleanup handled by atexit function */
   int error;
